/**
 * @file  DFFileDisplay.h
 * @brief Schnittstelle fuer die Klasse CDFFileDisplay.
 */
//////////////////////////////////////////////////////////////////////
#ifndef _DFFILEDISPLAY_H_
#define _DFFILEDISPLAY_H_

// Verwaltungsklasse fuer Datei
#include "IntelHex.h"
// 16bit/32bit CRC
#include "CRC.h"
// Fehlerzustaende
#include "ErrorState.h"

// Strukturdefinitionen
#include "PZEMAIV.h"

// Maximale Anzahl Datenbyte (128kByte)
#define MAX_MEM_FONT   0x10000
#define MAX_MEM_GRAFIC 0x10000

// Maximale Anzahl Zeichensaetze
#define MAX_FONT   10
// Maximale Anzahl der Grafiken
#define MAX_GRAFIC 64

class CDFFileDisplay : public CIntelHex
{
public:
	CDFFileDisplay();
	virtual ~CDFFileDisplay();

public:
	unsigned long m_sizeFont;
	unsigned long m_sizeGrafic;
	unsigned long m_sizeData;

	// Verwaltungsstrukturen fuer Zeichensatz
	FONTNODE *m_pFontNode;
	FONT     *m_pFont[MAX_FONT];

	// Verwaltungsstrukturen fuer Grafik
	GRAFICNODE *m_pGraficNode;
	GRAFIC     *m_pGrafic[MAX_GRAFIC];

	// Speicher fuer alle Daten
	unsigned char m_memFont[MAX_MEM_FONT];
	unsigned char m_memGrafic[MAX_MEM_GRAFIC];

protected:
	int m_errorState;

public:
	void Reset();
	inline int GetLastErrorState() { return m_errorState; };
	inline unsigned long GetSizeData() { return m_sizeData; };
	void Default(int iFontCount, int iGraficCount);
	void DefaultFont(int iCount);
	void DefaultGrafic(int iCount);
	void FontCorrect(int iNum);
	void SetFontNode(FONTNODE *pFontNode);
	void SetFont(int iNum, FONT *pFont);
	void SetGraficNode(FONTNODE *pGraficNode);
	void SetGrafic(int iNum, GRAFIC *pGrafic);

	int Load(char *fileName);
	int LoadFont(char *fileName);
	int LoadGrafic(char *fileName);
	int Save(char *fileName, unsigned char append = 0);
	int SaveFont(char *fileName, unsigned char append = 0);
	int SaveGrafic(char *fileName, unsigned char append = 0);
};

#endif

